TabbedDataset
=============

.. currentmodule:: pykeen.datasets.base

.. autoclass:: TabbedDataset
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~TabbedDataset.ratios

   .. rubric:: Attributes Documentation

   .. autoattribute:: ratios
